@@ -13,15 +13,15 @@ class UUIDColumn(FormatColumn):
 
     # UUID is stored by two uint64 numbers.
     def write_items(self, items, buf):
-        l = len(items)
+        n_items = len(items)
 
-        uint_64_pairs = [None] * 2 * l
+        uint_64_pairs = [None] * 2 * n_items
         for i, x in enumerate(items):
             i2 = 2 * i
             uint_64_pairs[i2] = (x >> 64) & MAX_UINT64
             uint_64_pairs[i2 + 1] = x & MAX_UINT64
 
-        s = self.make_struct(2 * l)
+        s = self.make_struct(2 * n_items)
         buf.write(s.pack(*uint_64_pairs))
 
     def read_items(self, n_items, buf):
