@@ -3,11 +3,20 @@ from struct import Struct
 
 def read_binary_str(buf):
     length = read_varint(buf)
-    return buf.read(length).decode('utf-8')
+    return read_binary_str_fixed_len(buf, length)
+
+
+def read_binary_bytes(buf):
+    length = read_varint(buf)
+    return read_binary_bytes_fixed_len(buf, length)
 
 
 def read_binary_str_fixed_len(buf, length):
-    return buf.read(length).decode('utf-8')
+    return read_binary_bytes_fixed_len(buf, length).decode('utf-8')
+
+
+def read_binary_bytes_fixed_len(buf, length):
+    return buf.read(length)
 
 
 def _read_one(f):
